@@ -161,4 +161,20 @@ def delComponentParam(componentOption, parameterName):
 	"""
 	paramDict = _buildDictionary(componentOption)
 	del paramDict[parameterName]
-	_writeParamField(componentOption, paramDict)
\ No newline at end of file
+	_writeParamField(componentOption, paramDict)
+	
+	
+def setPluginEnabled(pluginFolder, pluginElement, enable):
+	"""
+	Enable or disable a plugin by setting the published field for the plugin in the jos_plugins table
+	"""
+	
+	# database config
+	dbPW = getWebConfigDBPassword()
+	dbUserName = getWebConfigDBUsername()
+	dbName = getWebConfigDBName()	
+	db =  hubzero.data.db.mySql("localhost", dbName, dbUserName, dbPW)
+		
+	sql = "UPDATE jos_plugins set published = %s WHERE `folder` = %s AND `element` = %s"
+	data = (enable, pluginFolder, pluginElement)
+	db.execQuery(sql, data)	
